@@ -14,7 +14,7 @@ def consoleOut(identity,content):
 try:
     from lxml.html import etree
 except:
-    consoleOut("N0Code","Please run 'pip install lxml")
+    consoleOut("N0Code",I18n("Please run 'pip install lxml"))
     exit(0)
 import sys
 class Question:
@@ -170,7 +170,10 @@ Ans=N0Code.Answer("{Title}","{Description}","{Author}")'''
 def new(questionId=-1):
     if questionId==-1:
         questionId=args.questionId
-    author=args.author
+    if args.author==None:
+        author=Config["Author"]
+    else:
+        author=args.author
     if questionId==None:
         print(I18n("Lack of parameter")+" 'QuestionId'")
         return
@@ -302,7 +305,7 @@ if __name__ == "__main__":
     parser = argparse.ArgumentParser(description="For LeetCode,For Dream.\nDeveloped by N0P3.")
     parser.add_argument("option",choices=functions.keys(),help=I18n("Option."))
     parser.add_argument("questionId",nargs='?',help=I18n("Question Id."))
-    parser.add_argument("author",nargs='?',default='Unknow',help=I18n("Author."))
+    parser.add_argument("author",nargs='?',help=I18n("Author."))
     parser.add_argument("-l", "--language", help=I18n("Set language."),default="Default",choices=list(i18n.texts.keys()).append("En"))
     args = parser.parse_args()
     i18n.Language=args.language
