@@ -20,7 +20,8 @@ texts={
         "例",
         "描述",
         "标题",
-        "恭喜！你已经完成了所有的题目。"
+        "恭喜！你已经完成了所有的题目。",
+        "请执行'pip install lxml'"
     ]
 }
 main_text=[
@@ -43,7 +44,8 @@ main_text=[
     "Example",
     "Description",
     "Title",
-    "Congratulations! You have already finished all the questions."
+    "Congratulations! You have already finished all the questions.",
+    "Please run 'pip install lxml"
     
 ]
 def I18n(text):
